@@ -14,6 +14,7 @@ see http://www.gnu.org/licenses/.
 
 Author: Michael P. J. Camilleri
 """
+import glob
 
 from numba import jit, uint8, uint16, double
 from queue import Queue, Empty, Full
@@ -94,7 +95,7 @@ class Homography:
                 0: Use OpenCV's LeastSquares method
                 1: Use OpenCV's RANSAC: in this case, params MUST specify the inlier cutoff (in
                 terms of pixel distance) as a scalar.
-                10: Use my method based on BFGS and setting H_{3,3} = 1
+                10: Use my method based on Nelder-Mead and setting H_{3,3} = 1
         :param params: Parameters needed for each of the methods
                 MTHD_OPENCV_LS: ignored
                 MTHD_OPENCV_RNSC: Inlier cutoff, scalar
@@ -799,8 +800,6 @@ def line(img, pt1, pt2, color, thickness=1, lineType=8, shift=0, linestyle="-"):
             '.': Dotted line
         For other arguments, see cv2.line(). Note that lineType and shift are ignored if
         linestyle is not '-'
-
-    @TODO: Some fancy checks to ensure that line ends with a dash.
     """
 
     if linestyle == "-":
@@ -919,6 +918,9 @@ def point(img, center, color, size=1, style="."):
         cv2.circle(img, (int(center[0]), int(center[1])), size, color, -1)
     elif style == "o":
         cv2.circle(img, (int(center[0]), int(center[1])), size, color, int(math.ceil(size / 5)))
+    elif style == 'x':
+        ctr = (int(center[0] - 5*size), int(center[1] + 4*size))
+        cv2.putText(img, 'x', ctr, cv2.FONT_HERSHEY_PLAIN, size, color, size*2)
 
 
 class TimeFrame:
@@ -928,25 +930,32 @@ class TimeFrame:
     Note:
         time is always returned in MS.
         frames are by default 0-offset, but this can be changed in the initialiser
+        floor allows one to chose between flooring or rounding when converting non-numeric values.
     """
 
-    def __init__(self, fps=25, frm_offset=0):
+    def __init__(self, fps=25, frm_offset=0, floor=False):
         self.FPS = fps
         self.offset = frm_offset
+        self._round = np.floor if floor else np.around
 
     def to_frame(self, ms):
         if type(ms) == np.ndarray:
-            return (np.around(ms * self.FPS / 1000) + self.offset).astype(int)
+            return (self._round(ms * self.FPS / 1000) + self.offset).astype(int)
         else:
-            return int(np.round(ms * self.FPS / 1000) + self.offset)
+            return int(self._round(ms * self.FPS / 1000) + self.offset)
 
-    def to_time(self, frm):
-        return (frm - self.offset) * 1000 / self.FPS
+    def to_time(self, frm, ms=True):
+        if ms:
+            return (frm - self.offset) * 1000 / self.FPS
+        else:
+            return (frm - self.offset) / self.FPS
 
 
 class VideoParser:
     """
     The Video Parser (Wrapper) Object
+
+    **Note: May be deprecated soon in favour of decord**
     """
 
     def __init__(self, path, qsize=16):
@@ -1116,15 +1125,9 @@ class VideoParser:
             stream.set(cv2.CAP_PROP_POS_FRAMES, self.StartAt)
             assert stream.get(cv2.CAP_PROP_POS_FRAMES) == self.StartAt
 
-        # Store/Initialise some properties
-        self.properties[cv2.CAP_PROP_POS_MSEC] = stream.get(cv2.CAP_PROP_POS_MSEC)
-        self.properties[cv2.CAP_PROP_POS_FRAMES] = stream.get(cv2.CAP_PROP_POS_FRAMES)
-        self.properties[cv2.CAP_PROP_FRAME_HEIGHT] = stream.get(cv2.CAP_PROP_FRAME_HEIGHT)
-        self.properties[cv2.CAP_PROP_FRAME_WIDTH] = stream.get(cv2.CAP_PROP_FRAME_WIDTH)
-        self.properties[cv2.CAP_PROP_FPS] = stream.get(cv2.CAP_PROP_FPS)
-        self.properties[cv2.CAP_PROP_FRAME_COUNT] = stream.get(cv2.CAP_PROP_FRAME_COUNT)
-        self.properties[cv2.CAP_PROP_FOURCC] = stream.get(cv2.CAP_PROP_FOURCC)
-        self.properties[cv2.CAP_PROP_CONVERT_RGB] = stream.get(cv2.CAP_PROP_CONVERT_RGB)
+        # Store/Initialise CV2s properties
+        for prop in filter(lambda p: p >=0, self.properties.keys()):
+            self.properties[prop] = stream.get(prop)
 
         # Now indicate started
         self.signal_started = True
@@ -1200,6 +1203,19 @@ class FrameGetter:
             assert os.path.exists(_pth), f"Image {item} does not exist at {_pth}."
             return cv2.imread(_pth)
 
+    def __len__(self):
+        """
+        Retrieves the number of Frames
+
+        This is 'approximate', by counting the number of files matching the extension.
+
+        :return: Length
+        """
+        if self.Fmt.lower() == "video":
+            return int(cv2.VideoCapture(self.Path).get(cv2.CAP_PROP_FRAME_COUNT))
+        else:
+            return len(glob.glob(os.path.join(self.Path, f'*{os.path.splitext(self.Fmt)[1]}')))
+
 
 class SwCLAHE:
     """
